@@ -39,7 +39,8 @@ class Unpacker(Karton):
         parser = super().args_parser()
         parser.add_argument("--modules", help="Modules Directory", type=str, required=True)
         parser.add_argument("--rootfs", help="Emulator RootFS", type=str, default=None, required=False)
-        parser.add_argument("--timeout", help="Emulator Timeout", type=int, default=5000, required=False)
+        parser.add_argument("--emulator-timeout", help="Emulator Timeout", type=int, default=5000, required=False)
+        parser.add_argument("--timeout", help="Task Timeout in Seconds", type=int, default=30, required=False)
         parser.add_argument("--debug", help="Debug", action='store_true', default=False, required=False)
         return parser
 
@@ -51,6 +52,7 @@ class Unpacker(Karton):
         user_config = {
             'modules': args.modules,
             'rootfs': args.rootfs,
+            'emulator_timeout': args.emulator_timeout,
             'timeout': args.timeout,
             'debug': args.debug
         }
